^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Changelog for package rosx_introspection
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

2.0.1 (2025-10-01)
------------------
* Merge pull request `#21 <https://github.com/facontidavide/rosx_introspection/issues/21>`_ from bryzhao/fix/scikit-build-core-compatibility
  Fix CMakeLists to support scikit-build-core installations
* Fix CMakeLists to support scikit-build-core installations
* Merge pull request `#20 <https://github.com/facontidavide/rosx_introspection/issues/20>`_ from nealtanner/bugfix/mac-compliation
  fix compilation errors on mac
* replace sprintf with snprintf
* inline vs constexpr
* Contributors: Bryan Zhao, Davide Faconti, Neal Tanner

2.0.0 (2025-09-24)
------------------
* optionally remove JSON support
* new formatting
* fix memory and add README
* add python binding
* NanoCDR
* Merge pull request `#16 <https://github.com/facontidavide/rosx_introspection/issues/16>`_ from traversaro/patch-1
  Add missing include of functional header in message_definition_cache.cpp
* Fix issue `#13 <https://github.com/facontidavide/rosx_introspection/issues/13>`_
* Merge pull request `#11 <https://github.com/facontidavide/rosx_introspection/issues/11>`_ from valgur/bugfix/clang
  Fix ros_parser.cpp compilation failures on Clang
* Contributors: Davide Faconti, Martin Valgur, Silvio Traversaro

1.0.2 (2024-07-28)
------------------
* bug fix
* add unit tests
* Contributors: Davide Faconti

1.0.1 (2024-06-29)
------------------
* use CPM to download dependenies
* Merge pull request `#9 <https://github.com/facontidavide/rosx_introspection/issues/9>`_ from valgur/feature/cmake-improvements
* Contributors: Davide Faconti, Martin Valgur

1.0.0 (2024-06-26)
------------------
* New version including JSON conversion
* Contributors: Basavaraj-PN, Davide Faconti, ahmad-ra
